<div class="phileo">
    {% if can_like %}
        <a class="ajax"
           data-method="post"
           data-replace-closest=".phileo"
           data-spinner="off"
           href="{{ like_url }}">
            <i class="icon {{ like_class }}"></i>
            {{ like_text }}
        </a>
    {% endif %}
    <span class="count">
        {{ like_count }} {{ counts_text }}
    </span>
</div>
